@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct access allowed.');
+<?php defined('SYSPATH') or die('No direct access allowed.');
 
 return array(
 
@@ -6,6 +6,7 @@ return array(
 	'hash_method'  => 'sha256',
 	'hash_key'     => NULL,
 	'lifetime'     => 1209600,
+	'session_type' => Session::$default,
 	'session_key'  => 'auth_user',
 
 	// Username/password combinations for the Auth File driver
