@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 
 // Catch-all route for Codebench classes to run
 Route::set('codebench', 'codebench(/<class>)')
