@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 /**
  * Image manipulation support. Allows images to be resized, cropped, etc.
  *
@@ -16,7 +16,6 @@ abstract class Kohana_Image {
 	const HEIGHT  = 0x03;
 	const AUTO    = 0x04;
 	const INVERSE = 0x05;
-	const PRECISE = 0x06;
 
 	// Flipping directions
 	const HORIZONTAL = 0x11;
@@ -35,8 +34,8 @@ abstract class Kohana_Image {
 	 *
 	 *     $image = Image::factory('upload/test.jpg');
 	 *
-	 * @param   string   $file    image file path
-	 * @param   string   $driver  driver type: GD, ImageMagick, etc
+	 * @param   string   image file path
+	 * @param   string   driver type: GD, ImageMagick, etc
 	 * @return  Image
 	 * @uses    Image::$default_driver
 	 */
@@ -83,7 +82,7 @@ abstract class Kohana_Image {
 	 * Loads information about the image. Will throw an exception if the image
 	 * does not exist or is not an image.
 	 *
-	 * @param   string  $file  image file path
+	 * @param   string   image file path
 	 * @return  void
 	 * @throws  Kohana_Exception
 	 */
@@ -168,9 +167,9 @@ abstract class Kohana_Image {
 	 *     // Resize to 200x500 pixels, ignoring aspect ratio
 	 *     $image->resize(200, 500, Image::NONE);
 	 *
-	 * @param   integer  $width   new width
-	 * @param   integer  $height  new height
-	 * @param   integer  $master  master dimension
+	 * @param   integer  new width
+	 * @param   integer  new height
+	 * @param   integer  master dimension
 	 * @return  $this
 	 * @uses    Image::_do_resize
 	 */
@@ -248,19 +247,6 @@ abstract class Kohana_Image {
 				// Recalculate the width based on the height proportions
 				$width = $this->width * $height / $this->height;
 			break;
-			case Image::PRECISE:
-				// Resize to precise size
-				$ratio = $this->width / $this->height;
-
-				if ($width / $height > $ratio)
-				{
-					$height = $this->height * $width / $this->width;
-				}
-				else
-				{
-					$width = $this->width * $height / $this->height;
-				}
-			break;
 		}
 
 		// Convert the width and height to integers, minimum value is 1px
@@ -282,10 +268,10 @@ abstract class Kohana_Image {
 	 *     // Crop the image to 200x200 pixels, from the center
 	 *     $image->crop(200, 200);
 	 *
-	 * @param   integer  $width     new width
-	 * @param   integer  $height    new height
-	 * @param   mixed    $offset_x  offset from the left
-	 * @param   mixed    $offset_y  offset from the top
+	 * @param   integer  new width
+	 * @param   integer  new height
+	 * @param   mixed    offset from the left
+	 * @param   mixed    offset from the top
 	 * @return  $this
 	 * @uses    Image::_do_crop
 	 */
@@ -365,7 +351,7 @@ abstract class Kohana_Image {
 	 *     // Rotate 90% counter-clockwise
 	 *     $image->rotate(-90);
 	 *
-	 * @param   integer  $degrees  degrees to rotate: -360-360
+	 * @param   integer   degrees to rotate: -360-360
 	 * @return  $this
 	 * @uses    Image::_do_rotate
 	 */
@@ -381,7 +367,7 @@ abstract class Kohana_Image {
 				// Keep subtracting full circles until the degrees have normalized
 				$degrees -= 360;
 			}
-			while ($degrees > 180);
+			while($degrees > 180);
 		}
 
 		if ($degrees < -180)
@@ -391,7 +377,7 @@ abstract class Kohana_Image {
 				// Keep adding full circles until the degrees have normalized
 				$degrees += 360;
 			}
-			while ($degrees < -180);
+			while($degrees < -180);
 		}
 
 		$this->_do_rotate($degrees);
@@ -408,7 +394,7 @@ abstract class Kohana_Image {
 	 *     // Flip the image from left to right
 	 *     $image->flip(Image::VERTICAL);
 	 *
-	 * @param   integer  $direction  direction: Image::HORIZONTAL, Image::VERTICAL
+	 * @param   integer  direction: Image::HORIZONTAL, Image::VERTICAL
 	 * @return  $this
 	 * @uses    Image::_do_flip
 	 */
@@ -431,7 +417,7 @@ abstract class Kohana_Image {
 	 *     // Sharpen the image by 20%
 	 *     $image->sharpen(20);
 	 *
-	 * @param   integer  $amount  amount to sharpen: 1-100
+	 * @param   integer  amount to sharpen: 1-100
 	 * @return  $this
 	 * @uses    Image::_do_sharpen
 	 */
@@ -462,9 +448,9 @@ abstract class Kohana_Image {
 	 * [!!] By default, the reflection will be go from transparent at the top
 	 * to opaque at the bottom.
 	 *
-	 * @param   integer   $height   reflection height
-	 * @param   integer   $opacity  reflection opacity: 0-100
-	 * @param   boolean   $fade_in  TRUE to fade in, FALSE to fade out
+	 * @param   integer   reflection height
+	 * @param   integer   reflection opacity: 0-100
+	 * @param   boolean   TRUE to fade in, FALSE to fade out
 	 * @return  $this
 	 * @uses    Image::_do_reflection
 	 */
@@ -495,10 +481,10 @@ abstract class Kohana_Image {
 	 *     $mark = Image::factory('upload/watermark.png');
 	 *     $image->watermark($mark, TRUE, TRUE);
 	 *
-	 * @param   Image    $watermark  watermark Image instance
-	 * @param   integer  $offset_x   offset from the left
-	 * @param   integer  $offset_y   offset from the top
-	 * @param   integer  $opacity    opacity of watermark: 1-100
+	 * @param   object   watermark Image instance
+	 * @param   integer  offset from the left
+	 * @param   integer  offset from the top
+	 * @param   integer  opacity of watermark: 1-100
 	 * @return  $this
 	 * @uses    Image::_do_watermark
 	 */
@@ -554,8 +540,8 @@ abstract class Kohana_Image {
 	 *     // Make the image background black with 50% opacity
 	 *     $image->background('#000', 50);
 	 *
-	 * @param   string   $color    hexadecimal color value
-	 * @param   integer  $opacity  background opacity: 0-100
+	 * @param   string   hexadecimal color value
+	 * @param   integer  background opacity: 0-100
 	 * @return  $this
 	 * @uses    Image::_do_background
 	 */
@@ -599,8 +585,8 @@ abstract class Kohana_Image {
 	 * [!!] If the file does not exist, and the directory is not writable, an
 	 * exception will be thrown.
 	 *
-	 * @param   string   $file     new image path
-	 * @param   integer  $quality  quality of image: 1-100
+	 * @param   string   new image path
+	 * @param   integer  quality of image: 1-100
 	 * @return  boolean
 	 * @uses    Image::_save
 	 * @throws  Kohana_Exception
@@ -648,8 +634,8 @@ abstract class Kohana_Image {
 	 *     // Render the image as a PNG
 	 *     $data = $image->render('png');
 	 *
-	 * @param   string   $type     image type to return: png, jpg, gif, etc
-	 * @param   integer  $quality  quality of image: 1-100
+	 * @param   string   image type to return: png, jpg, gif, etc
+	 * @param   integer  quality of image: 1-100
 	 * @return  string
 	 * @uses    Image::_do_render
 	 */
@@ -667,8 +653,8 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a resize.
 	 *
-	 * @param   integer  $width   new width
-	 * @param   integer  $height  new height
+	 * @param   integer  new width
+	 * @param   integer  new height
 	 * @return  void
 	 */
 	abstract protected function _do_resize($width, $height);
@@ -676,10 +662,10 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a crop.
 	 *
-	 * @param   integer  $width     new width
-	 * @param   integer  $height    new height
-	 * @param   integer  $offset_x  offset from the left
-	 * @param   integer  $offset_y  offset from the top
+	 * @param   integer  new width
+	 * @param   integer  new height
+	 * @param   integer  offset from the left
+	 * @param   integer  offset from the top
 	 * @return  void
 	 */
 	abstract protected function _do_crop($width, $height, $offset_x, $offset_y);
@@ -687,7 +673,7 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a rotation.
 	 *
-	 * @param   integer  $degrees  degrees to rotate
+	 * @param   integer  degrees to rotate
 	 * @return  void
 	 */
 	abstract protected function _do_rotate($degrees);
@@ -695,7 +681,7 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a flip.
 	 *
-	 * @param   integer  $direction  direction to flip
+	 * @param   integer  direction to flip
 	 * @return  void
 	 */
 	abstract protected function _do_flip($direction);
@@ -703,7 +689,7 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a sharpen.
 	 *
-	 * @param   integer  $amount  amount to sharpen
+	 * @param   integer  amount to sharpen
 	 * @return  void
 	 */
 	abstract protected function _do_sharpen($amount);
@@ -711,9 +697,9 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a reflection.
 	 *
-	 * @param   integer   $height   reflection height
-	 * @param   integer   $opacity  reflection opacity
-	 * @param   boolean   $fade_in  TRUE to fade out, FALSE to fade in
+	 * @param   integer   reflection height
+	 * @param   integer   reflection opacity
+	 * @param   boolean   TRUE to fade out, FALSE to fade in
 	 * @return  void
 	 */
 	abstract protected function _do_reflection($height, $opacity, $fade_in);
@@ -721,10 +707,10 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a watermarking.
 	 *
-	 * @param   Image    $image     watermarking Image
-	 * @param   integer  $offset_x  offset from the left
-	 * @param   integer  $offset_y  offset from the top
-	 * @param   integer  $opacity   opacity of watermark
+	 * @param   object   watermarking Image
+	 * @param   integer  offset from the left
+	 * @param   integer  offset from the top
+	 * @param   integer  opacity of watermark
 	 * @return  void
 	 */
 	abstract protected function _do_watermark(Image $image, $offset_x, $offset_y, $opacity);
@@ -732,10 +718,10 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a background.
 	 *
-	 * @param   integer  $r        red
-	 * @param   integer  $g        green
-	 * @param   integer  $b        blue
-	 * @param   integer  $opacity  opacity
+	 * @param   integer  red
+	 * @param   integer  green
+	 * @param   integer  blue
+	 * @param   integer  opacity
 	 * @return void
 	 */
 	abstract protected function _do_background($r, $g, $b, $opacity);
@@ -743,8 +729,8 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a save.
 	 *
-	 * @param   string   $file     new image filename
-	 * @param   integer  $quality  quality
+	 * @param   string   new image filename
+	 * @param   integer  quality
 	 * @return  boolean
 	 */
 	abstract protected function _do_save($file, $quality);
@@ -752,8 +738,8 @@ abstract class Kohana_Image {
 	/**
 	 * Execute a render.
 	 *
-	 * @param   string    $type     image type: png, jpg, gif, etc
-	 * @param   integer   $quality  quality
+	 * @param   string    image type: png, jpg, gif, etc
+	 * @param   integer   quality
 	 * @return  string
 	 */
 	abstract protected function _do_render($type, $quality);
