@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 
 return array(
 	// Leave this alone
@@ -17,7 +17,7 @@ return array(
 			'description' => 'Image manipulation.',
 			
 			// Copyright message, shown in the footer for this module
-			'copyright' => '&copy; 2008–2012 Kohana Team',
+			'copyright' => '&copy; 2008–2010 Kohana Team',
 		)	
 	)
 );
\ No newline at end of file
