@@ -12,53 +12,6 @@
  * @author     Kohana Team
  * @copyright  (c) 2007-2010 Kohana Team
  * @license    http://kohanaframework.org/license
- *
- *
- * @method ORM where()
- * @method ORM and_where()
- * @method ORM or_where()
- * @method ORM where_open()
- * @method ORM and_where_open()
- * @method ORM or_where_open()
- * @method ORM where_close()
- * @method ORM and_where_close()
- * @method ORM or_where_close()
- * @method ORM distinct()
- * @method ORM select()
- * @method ORM from()
- * @method ORM join()
- * @method ORM on()
- * @method ORM group_by()
- * @method ORM having()
- * @method ORM and_having()
- * @method ORM or_having()
- * @method ORM having_open()
- * @method ORM and_having_open()
- * @method ORM or_having_open()
- * @method ORM having_close()
- * @method ORM and_having_close()
- * @method ORM or_having_close()
- * @method ORM order_by()
- * @method ORM limit()
- * @method ORM offset()
- * @method ORM cached()
- * @method Validation validation()
- *
- * @property string $object_name Name of the model
- * @property string $object_plural Plural name of the model
- * @property bool $loaded ORM object was loaded?
- * @property bool $saved ORM object was saved?
- * @property mixed $primary_key
- * @property mixed $primary_val
- * @property string $table_name
- * @property string $table_columns
- * @property array $has_one
- * @property array $belongs_to
- * @property array $has_many
- * @property array $has_many_through
- * @property array $load_with
- * @property string $updated_column
- * @property string $created_column
  */
 class Kohana_ORM extends Model implements serializable {
 
@@ -68,31 +21,6 @@ class Kohana_ORM extends Model implements serializable {
 	 */
 	protected static $_column_cache = array();
 
-	/**
-	 * Callable database methods
-	 * @var array
-	 */
-	protected static $_db_methods = array
-	(
-		'where', 'and_where', 'or_where', 'where_open', 'and_where_open', 'or_where_open', 'where_close',
-		'and_where_close', 'or_where_close', 'distinct', 'select', 'from', 'join', 'on', 'group_by',
-		'having', 'and_having', 'or_having', 'having_open', 'and_having_open', 'or_having_open',
-		'having_close', 'and_having_close', 'or_having_close', 'order_by', 'limit', 'offset', 'cached',
-	);
-
-	/**
-	 * Members that have access methods
-	 * @var array
-	 */
-	protected static $_properties = array
-	(
-		'object_name', 'object_plural', 'loaded', 'saved', // Object
-		'primary_key', 'primary_val', 'table_name', 'table_columns', // Table
-		'has_one', 'belongs_to', 'has_many', 'has_many_through', 'load_with', // Relationships
-		'updated_column', 'created_column',
-		'validation',
-	);
-
 	/**
 	 * Creates and returns a new model.
 	 *
@@ -150,6 +78,11 @@ class Kohana_ORM extends Model implements serializable {
 	 */
 	protected $_changed = array();
 
+	/**
+	 * @var array
+	 */
+	protected $_original_values = array();
+
 	/**
 	 * @var array
 	 */
@@ -217,6 +150,12 @@ class Kohana_ORM extends Model implements serializable {
 	 */
 	protected $_created_column = NULL;
 
+	/**
+	 * Auto-serialize and unserialize columns on get/set
+	 * @var array
+	 */
+	protected $_serialize_columns = array();
+
 	/**
 	 * Table primary key
 	 * @var string
@@ -289,6 +228,13 @@ class Kohana_ORM extends Model implements serializable {
 	 */
 	protected $_cast_data = array();
 
+	/**
+	 * The message filename used for validation errors.
+	 * Defaults to ORM::$_object_name
+	 * @var string
+	 */
+	protected $_errors_filename = NULL;
+
 	/**
 	 * Constructs a new model and loads a record if given
 	 *
@@ -314,7 +260,7 @@ class Kohana_ORM extends Model implements serializable {
 			else
 			{
 				// Passing the primary key
-				$this->where($this->_table_name.'.'.$this->_primary_key, '=', $id)->find();
+				$this->where($this->_object_name.'.'.$this->_primary_key, '=', $id)->find();
 			}
 		}
 		elseif ( ! empty($this->_cast_data))
@@ -338,6 +284,11 @@ class Kohana_ORM extends Model implements serializable {
 		$this->_object_name = strtolower(substr(get_class($this), 6));
 		$this->_object_plural = Inflector::plural($this->_object_name);
 
+		if ( ! $this->_errors_filename)
+		{
+			$this->_errors_filename = $this->_object_name;
+		}
+
 		if ( ! is_object($this->_db))
 		{
 			// Get database instance
@@ -398,7 +349,9 @@ class Kohana_ORM extends Model implements serializable {
 	{
 		// Build the validation object with its rules
 		$this->_validation = Validation::factory($this->_object)
-			->bind(':model', $this);
+			->bind(':model', $this)
+			->bind(':original_values', $this->_original_values)
+			->bind(':changed', $this->_changed);
 
 		foreach ($this->rules() as $field => $rules)
 		{
@@ -458,7 +411,7 @@ class Kohana_ORM extends Model implements serializable {
 		$values = array_combine(array_keys($this->_table_columns), array_fill(0, count($this->_table_columns), NULL));
 
 		// Replace the object and reset the object status
-		$this->_object = $this->_changed = $this->_related = array();
+		$this->_object = $this->_changed = $this->_related = $this->_original_values = array();
 
 		// Replace the current object with an empty one
 		$this->_load_values($values);
@@ -482,12 +435,12 @@ class Kohana_ORM extends Model implements serializable {
 		$primary_key = $this->pk();
 
 		// Replace the object and reset the object status
-		$this->_object = $this->_changed = $this->_related = array();
+		$this->_object = $this->_changed = $this->_related = $this->_original_values = array();
 
 		// Only reload the object if we have one to reload
 		if ($this->_loaded)
 			return $this->clear()
-				->where($this->_table_name.'.'.$this->_primary_key, '=', $primary_key)
+				->where($this->_object_name.'.'.$this->_primary_key, '=', $primary_key)
 				->find();
 		else
 			return $this->clear();
@@ -538,7 +491,7 @@ class Kohana_ORM extends Model implements serializable {
 	public function serialize()
 	{
 		// Store only information about the object
-		foreach (array('_primary_key_value', '_object', '_changed', '_loaded', '_saved', '_sorting') as $var)
+		foreach (array('_primary_key_value', '_object', '_changed', '_loaded', '_saved', '_sorting', '_original_values') as $var)
 		{
 			$data[$var] = $this->{$var};
 		}
@@ -546,6 +499,20 @@ class Kohana_ORM extends Model implements serializable {
 		return serialize($data);
 	}
 
+	/**
+	 * Check whether the model data has been modified.
+	 * If $field is specified, checks whether that field was modified.
+	 *
+	 * @param string  field to check for changes
+	 * @return  bool  Whether or not the field has changed
+	 */
+	public function changed($field = NULL)
+	{
+		return ($field === NULL)
+			? $this->_changed
+			: Arr::get($this->_changed, $field);
+	}
+
 	/**
 	 * Prepares the database connection and reloads the object.
 	 *
@@ -569,45 +536,6 @@ class Kohana_ORM extends Model implements serializable {
 		}
 	}
 
-	/**
-	 * Handles pass-through to database methods. Calls to query methods
-	 * (query, get, insert, update) are not allowed. Query builder methods
-	 * are chainable.
-	 *
-	 * @param   string  $method Method name
-	 * @param   array   $args   Method arguments
-	 * @return  mixed
-	 */
-	public function __call($method, array $args)
-	{
-		if (in_array($method, ORM::$_properties))
-		{
-			if ($method === 'validation')
-			{
-				if ( ! isset($this->_validation))
-				{
-					// Initialize the validation object
-					$this->_validation();
-				}
-			}
-
-			// Return the property
-			return $this->{'_'.$method};
-		}
-		elseif (in_array($method, ORM::$_db_methods))
-		{
-			// Add pending database call which is executed after query type is determined
-			$this->_db_pending[] = array('name' => $method, 'args' => $args);
-
-			return $this;
-		}
-		else
-		{
-			throw new Kohana_Exception('Invalid method :method called in :class',
-				array(':method' => $method, ':class' => get_class($this)));
-		}
-	}
-
 	/**
 	 * Handles retrieval of all model values, relationships, and metadata.
 	 *
@@ -618,7 +546,9 @@ class Kohana_ORM extends Model implements serializable {
 	{
 		if (array_key_exists($column, $this->_object))
 		{
-			return $this->_object[$column];
+			return (in_array($column, $this->_serialize_columns))
+				? $this->_unserialize_value($this->_object[$column])
+				: $this->_object[$column];
 		}
 		elseif (isset($this->_related[$column]))
 		{
@@ -630,7 +560,7 @@ class Kohana_ORM extends Model implements serializable {
 			$model = $this->_related($column);
 
 			// Use this model's column and foreign model's primary key
-			$col = $model->_table_name.'.'.$model->_primary_key;
+			$col = $model->_object_name.'.'.$model->_primary_key;
 			$val = $this->_object[$this->_belongs_to[$column]['foreign_key']];
 
 			$model->where($col, '=', $val)->find();
@@ -642,7 +572,7 @@ class Kohana_ORM extends Model implements serializable {
 			$model = $this->_related($column);
 
 			// Use this model's primary key value and foreign model's column
-			$col = $model->_table_name.'.'.$this->_has_one[$column]['foreign_key'];
+			$col = $model->_object_name.'.'.$this->_has_one[$column]['foreign_key'];
 			$val = $this->pk();
 
 			$model->where($col, '=', $val)->find();
@@ -660,7 +590,7 @@ class Kohana_ORM extends Model implements serializable {
 
 				// Join on through model's target foreign key (far_key) and target model's primary key
 				$join_col1 = $through.'.'.$this->_has_many[$column]['far_key'];
-				$join_col2 = $model->_table_name.'.'.$model->_primary_key;
+				$join_col2 = $model->_object_name.'.'.$model->_primary_key;
 
 				$model->join($through)->on($join_col1, '=', $join_col2);
 
@@ -671,7 +601,7 @@ class Kohana_ORM extends Model implements serializable {
 			else
 			{
 				// Simple has_many relationship, search where target model's foreign key is this model's primary key
-				$col = $model->_table_name.'.'.$this->_has_many[$column]['foreign_key'];
+				$col = $model->_object_name.'.'.$this->_has_many[$column]['foreign_key'];
 				$val = $this->pk();
 			}
 
@@ -714,6 +644,11 @@ class Kohana_ORM extends Model implements serializable {
 	 */
 	public function set($column, $value)
 	{
+		if (in_array($column, $this->_serialize_columns))
+		{
+			$value = $this->_serialize_value($value);
+		}
+
 		if (array_key_exists($column, $this->_object))
 		{
 			// Filter the data
@@ -860,7 +795,7 @@ class Kohana_ORM extends Model implements serializable {
 		if (empty($parent_path))
 		{
 			// Use this table name itself for the parent path
-			$parent_path = $this->_table_name;
+			$parent_path = $this->_object_name;
 		}
 		else
 		{
@@ -918,10 +853,10 @@ class Kohana_ORM extends Model implements serializable {
 				$this->_db_builder = DB::select();
 			break;
 			case Database::UPDATE:
-				$this->_db_builder = DB::update($this->_table_name);
+				$this->_db_builder = DB::update(array($this->_table_name, $this->_object_name));
 			break;
 			case Database::DELETE:
-				$this->_db_builder = DB::delete($this->_table_name);
+				$this->_db_builder = DB::delete(array($this->_table_name, $this->_object_name));
 		}
 
 		// Process pending database method calls
@@ -997,7 +932,7 @@ class Kohana_ORM extends Model implements serializable {
 	 */
 	protected function _load_result($multiple = FALSE)
 	{
-		$this->_db_builder->from($this->_table_name);
+		$this->_db_builder->from(array($this->_table_name, $this->_object_name));
 
 		if ($multiple === FALSE)
 		{
@@ -1006,7 +941,7 @@ class Kohana_ORM extends Model implements serializable {
 		}
 
 		// Select all columns by default
-		$this->_db_builder->select($this->_table_name.'.*');
+		$this->_db_builder->select($this->_object_name.'.*');
 
 		if ( ! isset($this->_db_applied['order_by']) AND ! empty($this->_sorting))
 		{
@@ -1015,7 +950,7 @@ class Kohana_ORM extends Model implements serializable {
 				if (strpos($column, '.') === FALSE)
 				{
 					// Sorting column for use in JOINs
-					$column = $this->_table_name.'.'.$column;
+					$column = $this->_object_name.'.'.$column;
 				}
 
 				$this->_db_builder->order_by($column, $direction);
@@ -1066,16 +1001,16 @@ class Kohana_ORM extends Model implements serializable {
 		{
 			if ($values[$this->_primary_key] !== NULL)
 			{
-				// Flag as loaded, saved, and valid
-				$this->_loaded = $this->_saved = $this->_valid = TRUE;
+				// Flag as loaded and valid
+				$this->_loaded = $this->_valid = TRUE;
 
 				// Store primary key
 				$this->_primary_key_value = $values[$this->_primary_key];
 			}
 			else
 			{
-				// Not loaded, saved, or valid
-				$this->_loaded = $this->_saved = $this->_valid = FALSE;
+				// Not loaded or valid
+				$this->_loaded = $this->_valid = FALSE;
 			}
 		}
 
@@ -1107,6 +1042,12 @@ class Kohana_ORM extends Model implements serializable {
 			}
 		}
 
+		if ($this->_loaded)
+		{
+			// Store the object in its original state
+			$this->_original_values = $this->_object;
+		}
+
 		return $this;
 	}
 
@@ -1230,7 +1171,7 @@ class Kohana_ORM extends Model implements serializable {
 
 		if (($this->_valid = $array->check()) === FALSE OR $extra_errors)
 		{
-			$exception = new ORM_Validation_Exception($this->_object_name, $array);
+			$exception = new ORM_Validation_Exception($this->errors_filename(), $array);
 
 			if ($extra_errors)
 			{
@@ -1291,6 +1232,7 @@ class Kohana_ORM extends Model implements serializable {
 
 		// All changes have been saved
 		$this->_changed = array();
+		$this->_original_values = $this->_object;
 
 		return $this;
 	}
@@ -1355,6 +1297,7 @@ class Kohana_ORM extends Model implements serializable {
 
 		// All changes have been saved
 		$this->_changed = array();
+		$this->_original_values = $this->_object;
 
 		return $this;
 	}
@@ -1403,13 +1346,23 @@ class Kohana_ORM extends Model implements serializable {
 	 *     $model->has('roles', 5);
 	 *     // Check for all of the following roles
 	 *     $model->has('roles', array(1, 2, 3, 4));
-
+	 *     // Check if $model has any roles
+	 *     $model->has('roles')
+	 *
 	 * @param  string  $alias    Alias of the has_many "through" relationship
 	 * @param  mixed   $far_keys Related model, primary key, or an array of primary keys
 	 * @return Database_Result
 	 */
-	public function has($alias, $far_keys)
+	public function has($alias, $far_keys = NULL)
 	{
+		if ($far_keys === NULL)
+		{
+			return (bool) DB::select(array('COUNT("*")', 'records_found'))
+				->from($this->_has_many[$alias]['through'])
+				->where($this->_has_many[$alias]['foreign_key'], '=', $this->pk())
+				->execute($this->_db)->get('records_found');
+		}
+
 		$far_keys = ($far_keys instanceof ORM) ? $far_keys->pk() : $far_keys;
 
 		// We need an array to simplify the logic
@@ -1526,7 +1479,7 @@ class Kohana_ORM extends Model implements serializable {
 
 		$this->_build(Database::SELECT);
 
-		$records = $this->_db_builder->from($this->_table_name)
+		$records = $this->_db_builder->from(array($this->_table_name, $this->_object_name))
 			->select(array('COUNT("*")', 'records_found'))
 			->execute($this->_db)
 			->get('records_found');
@@ -1551,23 +1504,6 @@ class Kohana_ORM extends Model implements serializable {
 		return $this->_db->list_columns($this->_table_name);
 	}
 
-	/**
-	 * Proxy method to Database field_data.
-	 *
-	 * @chainable
-	 * @param  string $sql SQL query to clear
-	 * @return ORM
-	 */
-	public function clear_cache($sql = NULL)
-	{
-		// Proxy to database
-		$this->_db->clear_cache($sql);
-
-		ORM::$_column_cache = array();
-
-		return $this;
-	}
-
 	/**
 	 * Returns an ORM model for the given one-one related alias
 	 *
@@ -1636,4 +1572,605 @@ class Kohana_ORM extends Model implements serializable {
 
 		return $this;
 	}
+
+	protected function _serialize_value($value)
+	{
+		return json_encode($value);
+	}
+
+	protected function _unserialize_value($value)
+	{
+		return json_decode($value);
+	}
+
+	public function object_name()
+	{
+		return $this->_object_name;
+	}
+
+	public function object_plural()
+	{
+		return $this->_object_plural;
+	}
+
+	public function loaded()
+	{
+		return $this->_loaded;
+	}
+
+	public function saved()
+	{
+		return $this->_saved;
+	}
+
+	public function primary_key()
+	{
+		return $this->_primary_key;
+	}
+
+	public function table_name()
+	{
+		return $this->_table_name;
+	}
+
+	public function table_columns()
+	{
+		return $this->_table_columns;
+	}
+
+	public function has_one()
+	{
+		return $this->_has_one;
+	}
+
+	public function belongs_to()
+	{
+		return $this->_belongs_to;
+	}
+
+	public function has_many()
+	{
+		return $this->_has_many;
+	}
+
+	public function load_with()
+	{
+		return $this->_load_with;
+	}
+
+	public function original_values()
+	{
+		return $this->_original_values;
+	}
+
+	public function created_column()
+	{
+		return $this->_created_column;
+	}
+
+	public function updated_column()
+	{
+		return $this->_updated_column;
+	}
+
+	public function validation()
+	{
+		if ( ! isset($this->_validation))
+		{
+			// Initialize the validation object
+			$this->_validation();
+		}
+
+		return $this->_validation;
+	}
+
+	public function object()
+	{
+		return $this->_object;
+	}
+
+	public function errors_filename()
+	{
+		return $this->_errors_filename;
+	}
+
+	/**
+	 * Alias of and_where()
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  logic operator
+	 * @param   mixed   column value
+	 * @return  $this
+	 */
+	public function where($column, $op, $value)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'where',
+			'args' => array($column, $op, $value),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Creates a new "AND WHERE" condition for the query.
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  logic operator
+	 * @param   mixed   column value
+	 * @return  $this
+	 */
+	public function and_where($column, $op, $value)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'and_where',
+			'args' => array($column, $op, $value),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Creates a new "OR WHERE" condition for the query.
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  logic operator
+	 * @param   mixed   column value
+	 * @return  $this
+	 */
+	public function or_where($column, $op, $value)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'or_where',
+			'args' => array($column, $op, $value),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Alias of and_where_open()
+	 *
+	 * @return  $this
+	 */
+	public function where_open()
+	{
+		return $this->and_where_open();
+	}
+
+	/**
+	 * Opens a new "AND WHERE (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function and_where_open()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'and_where_open',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Opens a new "OR WHERE (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function or_where_open()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'or_where_open',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Closes an open "AND WHERE (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function where_close()
+	{
+		return $this->and_where_close();
+	}
+
+	/**
+	 * Closes an open "AND WHERE (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function and_where_close()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'and_where_close',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Closes an open "OR WHERE (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function or_where_close()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'or_where_close',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Applies sorting with "ORDER BY ..."
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  direction of sorting
+	 * @return  $this
+	 */
+	public function order_by($column, $direction = NULL)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'order_by',
+			'args' => array($column, $direction),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Return up to "LIMIT ..." results
+	 *
+	 * @param   integer  maximum results to return
+	 * @return  $this
+	 */
+	public function limit($number)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'limit',
+			'args' => array($number),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Enables or disables selecting only unique columns using "SELECT DISTINCT"
+	 *
+	 * @param   boolean  enable or disable distinct columns
+	 * @return  $this
+	 */
+	public function distinct($value)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'distinct',
+			'args' => array($value),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Choose the columns to select from.
+	 *
+	 * @param   mixed  column name or array($column, $alias) or object
+	 * @param   ...
+	 * @return  $this
+	 */
+	public function select($columns = NULL)
+	{
+		$columns = func_get_args();
+
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'select',
+			'args' => $columns,
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Choose the tables to select "FROM ..."
+	 *
+	 * @param   mixed  table name or array($table, $alias) or object
+	 * @param   ...
+	 * @return  $this
+	 */
+	public function from($tables)
+	{
+		$tables = func_get_args();
+
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'from',
+			'args' => $tables,
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Adds addition tables to "JOIN ...".
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  join type (LEFT, RIGHT, INNER, etc)
+	 * @return  $this
+	 */
+	public function join($table, $type = NULL)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'join',
+			'args' => array($table, $type),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Adds "ON ..." conditions for the last created JOIN statement.
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  logic operator
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @return  $this
+	 */
+	public function on($c1, $op, $c2)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'on',
+			'args' => array($c1, $op, $c2),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Creates a "GROUP BY ..." filter.
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   ...
+	 * @return  $this
+	 */
+	public function group_by($columns)
+	{
+		$columns = func_get_args();
+
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'group_by',
+			'args' => $columns,
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Alias of and_having()
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  logic operator
+	 * @param   mixed   column value
+	 * @return  $this
+	 */
+	public function having($column, $op, $value = NULL)
+	{
+		return $this->and_having($column, $op, $value);
+	}
+
+	/**
+	 * Creates a new "AND HAVING" condition for the query.
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  logic operator
+	 * @param   mixed   column value
+	 * @return  $this
+	 */
+	public function and_having($column, $op, $value = NULL)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'and_having',
+			'args' => array($column, $op, $value),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Creates a new "OR HAVING" condition for the query.
+	 *
+	 * @param   mixed   column name or array($column, $alias) or object
+	 * @param   string  logic operator
+	 * @param   mixed   column value
+	 * @return  $this
+	 */
+	public function or_having($column, $op, $value = NULL)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'or_having',
+			'args' => array($column, $op, $value),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Alias of and_having_open()
+	 *
+	 * @return  $this
+	 */
+	public function having_open()
+	{
+		return $this->and_having_open();
+	}
+
+	/**
+	 * Opens a new "AND HAVING (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function and_having_open()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'and_having_open',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Opens a new "OR HAVING (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function or_having_open()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'or_having_open',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Closes an open "AND HAVING (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function having_close()
+	{
+		return $this->and_having_close();
+	}
+
+	/**
+	 * Closes an open "AND HAVING (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function and_having_close()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'and_having_close',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Closes an open "OR HAVING (...)" grouping.
+	 *
+	 * @return  $this
+	 */
+	public function or_having_close()
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'or_having_close',
+			'args' => array(),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Start returning results after "OFFSET ..."
+	 *
+	 * @param   integer   starting result number
+	 * @return  $this
+	 */
+	public function offset($number)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'offset',
+			'args' => array($number),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Enables the query to be cached for a specified amount of time.
+	 *
+	 * @param   integer  number of seconds to cache
+	 * @return  $this
+	 * @uses    Kohana::$cache_life
+	 */
+	public function cached($lifetime = NULL)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'cached',
+			'args' => array($lifetime),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Set the value of a parameter in the query.
+	 *
+	 * @param   string   parameter key to replace
+	 * @param   mixed    value to use
+	 * @return  $this
+	 */
+	public function param($param, $value)
+	{
+		// Add pending database call which is executed after query type is determined
+		$this->_db_pending[] = array(
+			'name' => 'param',
+			'args' => array($param, $value),
+		);
+
+		return $this;
+	}
+
+	/**
+	 * Checks whether a column value is unique.
+	 * Excludes itself if loaded.
+	 *
+	 * @param   string   the field to check for uniqueness
+	 * @param   mixed    the value to check for uniqueness
+	 * @return  bool     whteher the value is unique
+	 */
+	public function unique($field, $value)
+	{
+		$model = ORM::factory($this->object_name())
+			->where($field, '=', $value)
+			->find();
+
+		if ($this->loaded())
+		{
+			return ( ! ($model->loaded() AND $model->pk() != $this->pk()));
+		}
+
+		return ( ! $model->loaded());
+	}
 } // End ORM
