@@ -1,21 +1,16 @@
-<?php defined('SYSPATH') OR die('No direct access allowed.');
+<?php defined('SYSPATH') or die('No direct access allowed.');
 /**
  * Default auth user toke
  *
  * @package    Kohana/Auth
  * @author     Kohana Team
- * @copyright  (c) 2007-2012 Kohana Team
+ * @copyright  (c) 2007-2011 Kohana Team
  * @license    http://kohanaframework.org/license
  */
 class Model_Auth_User_Token extends ORM {
 
 	// Relationships
 	protected $_belongs_to = array('user' => array());
-	
-	protected $_created_column = array(
-		'column' => 'created',
-		'format' => TRUE,
-	);
 
 	/**
 	 * Handles garbage collection and deleting of expired objects.
