@@ -1,3 +1,3 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 
 abstract class Kodoc_Missing extends Kohana_Kodoc_Missing {  }
