@@ -4,14 +4,11 @@ return array
 (
 	// Enable the API browser.  TRUE or FALSE
 	'api_browser'  => TRUE,
-
+	
 	// Enable these packages in the API browser.  TRUE for all packages, or a string of comma seperated packages, using 'None' for a class with no @package
 	// Example: 'api_packages' => 'Kohana,Kohana/Database,Kohana/ORM,None',
 	'api_packages' => TRUE,
-
-	// Enables Disqus comments on the API and User Guide pages
-	'show_comments' => Kohana::$environment === Kohana::PRODUCTION,
-
+	
 	// Leave this alone
 	'modules' => array(
 
@@ -20,10 +17,7 @@ return array
 
 			// Whether this modules userguide pages should be shown
 			'enabled' => TRUE,
-
-			// Name of the start/landing/home page
-			'index' => 'index',
-
+			
 			// The name that should show up on the userguide index page
 			'name' => 'Userguide',
 
@@ -31,7 +25,7 @@ return array
 			'description' => 'Documentation viewer and api generation.',
 			
 			// Copyright message, shown in the footer for this module
-			'copyright' => '&copy; 2008–2012 Kohana Team',
+			'copyright' => '&copy; 2008–2011 Kohana Team',
 		)	
 	)
 );
