@@ -1,3 +1,3 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 
 class HTTP_Exception_400 extends Kohana_HTTP_Exception_400 {}
\ No newline at end of file
