@@ -25,13 +25,13 @@ abstract class Kohana_Controller_Template extends Controller {
 	 */
 	public function before()
 	{
+		parent::before();
+
 		if ($this->auto_render === TRUE)
 		{
 			// Load the template
 			$this->template = View::factory($this->template);
 		}
-
-		return parent::before();
 	}
 
 	/**
@@ -44,7 +44,7 @@ abstract class Kohana_Controller_Template extends Controller {
 			$this->response->body($this->template->render());
 		}
 
-		return parent::after();
+		parent::after();
 	}
 
 } // End Controller_Template
