@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 
 class Kohana_HTTP_Exception_408 extends HTTP_Exception {
 
