@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 /**
  * A HTTP Reponse specific interface that adds the methods required
  * by HTTP responses. Over and above [Kohana_HTTP_Interaction], this
@@ -11,7 +11,7 @@
  * @copyright  (c) 2008-2012 Kohana Team
  * @license    http://kohanaphp.com/license
  */
-interface Kohana_HTTP_Response extends HTTP_Interaction {
+interface Kohana_HTTP_Response extends HTTP_Message {
 
 	/**
 	 * Sets or gets the HTTP status from this response.
