@@ -5,16 +5,16 @@
  * @package    Kohana
  * @category   Logging
  * @author     Kohana Team
- * @copyright  (c) 2008-2011 Kohana Team
+ * @copyright  (c) 2008-2012 Kohana Team
  * @license    http://kohanaphp.com/license
  */
-class Kohana_Log_StdErr extends Kohana_Log_Writer {
+class Kohana_Log_StdErr extends Log_Writer {
 	/**
 	 * Writes each of the messages to STDERR.
 	 *
 	 *     $writer->write($messages);
 	 *
-	 * @param   array   messages
+	 * @param   array   $messages
 	 * @return  void
 	 */
 	public function write(array $messages)
