@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 /**
  * Request and response wrapper. Uses the [Route] class to determine what
  * [Controller] to send the request to.
@@ -21,6 +21,11 @@ class Kohana_Request implements HTTP_Request {
 	 */
 	public static $client_ip = '0.0.0.0';
 
+	/**
+	 * @var  string  trusted proxy server IPs
+	 */
+	public static $trusted_proxies = array('127.0.0.1', 'localhost', 'localhost.localdomain');
+
 	/**
 	 * @var  Request  main request instance
 	 */
@@ -43,12 +48,12 @@ class Kohana_Request implements HTTP_Request {
 	 * @param   string  $uri URI of the request
 	 * @param   Cache   $cache
 	 * @param   array   $injected_routes an array of routes to use, for testing
-	 * @return  void
-	 * @throws  Kohana_Request_Exception
+	 * @return  void|Request
+	 * @throws  Request_Exception
 	 * @uses    Route::all
 	 * @uses    Route::matches
 	 */
-	public static function factory($uri = TRUE, Cache $cache = NULL, $injected_routes = array())
+	public static function factory($uri = TRUE, HTTP_Cache $cache = NULL, $injected_routes = array())
 	{
 		// If this is the initial request
 		if ( ! Request::$initial)
@@ -101,6 +106,15 @@ class Kohana_Request implements HTTP_Request {
 			}
 			else
 			{
+				if (isset($_SERVER['SERVER_PROTOCOL']))
+				{
+					$protocol = $_SERVER['SERVER_PROTOCOL'];
+				}
+				else
+				{
+					$protocol = HTTP::$protocol;
+				}
+
 				if (isset($_SERVER['REQUEST_METHOD']))
 				{
 					// Use the server request method
@@ -115,11 +129,7 @@ class Kohana_Request implements HTTP_Request {
 				if ( ! empty($_SERVER['HTTPS']) AND filter_var($_SERVER['HTTPS'], FILTER_VALIDATE_BOOLEAN))
 				{
 					// This request is secure
-					$protocol = 'https';
-				}
-				else
-				{
-					$protocol = 'http';
+					$secure = TRUE;
 				}
 
 				if (isset($_SERVER['HTTP_REFERER']))
@@ -140,17 +150,30 @@ class Kohana_Request implements HTTP_Request {
 					$requested_with = $_SERVER['HTTP_X_REQUESTED_WITH'];
 				}
 
-				if (isset($_SERVER['HTTP_X_FORWARDED_FOR']))
+				if (isset($_SERVER['HTTP_X_FORWARDED_FOR'])
+				    AND isset($_SERVER['REMOTE_ADDR'])
+				    AND in_array($_SERVER['REMOTE_ADDR'], Request::$trusted_proxies))
 				{
 					// Use the forwarded IP address, typically set when the
 					// client is using a proxy server.
-					Request::$client_ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
+					// Format: "X-Forwarded-For: client1, proxy1, proxy2"
+					$client_ips = explode(',', $_SERVER['HTTP_X_FORWARDED_FOR']);
+
+					Request::$client_ip = array_shift($client_ips);
+
+					unset($client_ips);
 				}
-				elseif (isset($_SERVER['HTTP_CLIENT_IP']))
+				elseif (isset($_SERVER['HTTP_CLIENT_IP'])
+				        AND isset($_SERVER['REMOTE_ADDR'])
+				        AND in_array($_SERVER['REMOTE_ADDR'], Request::$trusted_proxies))
 				{
 					// Use the forwarded IP address, typically set when the
 					// client is using a proxy server.
-					Request::$client_ip = $_SERVER['HTTP_CLIENT_IP'];
+					$client_ips = explode(',', $_SERVER['HTTP_CLIENT_IP']);
+
+					Request::$client_ip = array_shift($client_ips);
+
+					unset($client_ips);
 				}
 				elseif (isset($_SERVER['REMOTE_ADDR']))
 				{
@@ -158,7 +181,7 @@ class Kohana_Request implements HTTP_Request {
 					Request::$client_ip = $_SERVER['REMOTE_ADDR'];
 				}
 
-				if ($method !== 'GET')
+				if ($method !== HTTP_Request::GET)
 				{
 					// Ensure the raw body is saved for future use
 					$body = file_get_contents('php://input');
@@ -185,13 +208,14 @@ class Kohana_Request implements HTTP_Request {
 			Request::$initial = $request = new Request($uri, $cache, $injected_routes);
 
 			// Store global GET and POST data in the initial request only
-			$request->query($_GET);
-			$request->post($_POST);
+			$request->protocol($protocol)
+				->query($_GET)
+				->post($_POST);
 
-			if (isset($protocol))
+			if (isset($secure))
 			{
-				// Set the request protocol
-				$request->protocol($protocol);
+				// Set the request security
+				$request->secure($secure);
 			}
 
 			if (isset($method))
@@ -357,7 +381,7 @@ class Kohana_Request implements HTTP_Request {
 	 *
 	 * @param   mixed   $value String to return: browser, version, robot, mobile, platform; or array of values
 	 * @return  mixed   requested information, FALSE if nothing is found
-	 * @uses    Kohana::config
+	 * @uses    Kohana::$config
 	 * @uses    Request::$user_agent
 	 */
 	public static function user_agent($value)
@@ -385,7 +409,7 @@ class Kohana_Request implements HTTP_Request {
 		if ($value === 'browser' OR $value == 'version')
 		{
 			// Load browsers
-			$browsers = Kohana::config('user_agents')->browser;
+			$browsers = Kohana::$config->load('user_agents')->browser;
 
 			foreach ($browsers as $search => $name)
 			{
@@ -412,7 +436,7 @@ class Kohana_Request implements HTTP_Request {
 		else
 		{
 			// Load the search group for this type
-			$group = Kohana::config('user_agents')->$value;
+			$group = Kohana::$config->load('user_agents')->$value;
 
 			foreach ($group as $search => $name)
 			{
@@ -641,6 +665,11 @@ class Kohana_Request implements HTTP_Request {
 	 */
 	protected $_protocol;
 
+	/**
+	 * @var  boolean
+	 */
+	protected $_secure = FALSE;
+
 	/**
 	 * @var  string  referring URL
 	 */
@@ -731,20 +760,20 @@ class Kohana_Request implements HTTP_Request {
 	 * be retrieved from the cache.
 	 *
 	 * @param   string  $uri URI of the request
-	 * @param   Cache   $cache
+	 * @param   HTTP_Cache   $cache
 	 * @param   array   $injected_routes an array of routes to use, for testing
 	 * @return  void
-	 * @throws  Kohana_Request_Exception
+	 * @throws  Request_Exception
 	 * @uses    Route::all
 	 * @uses    Route::matches
 	 */
-	public function __construct($uri, Cache $cache = NULL, $injected_routes = array())
+	public function __construct($uri, HTTP_Cache $cache = NULL, $injected_routes = array())
 	{
 		// Initialise the header
 		$this->_header = new HTTP_Header(array());
 
 		// Assign injected routes
-		$this->_injected_routes = $injected_routes;
+		$this->_routes = $injected_routes;
 
 		// Cleanse query parameters from URI (faster that parse_url())
 		$split_uri = explode('?', $uri);
@@ -768,13 +797,14 @@ class Kohana_Request implements HTTP_Request {
 			// Remove trailing slashes from the URI
 			$uri = trim($uri, '/');
 
-			$processed_uri = Request::process_uri($uri, $this->_injected_routes);
+			$processed_uri = Request::process_uri($uri, $this->_routes);
 
+			// Return here rather than throw exception. This will allow
+			// use of Request object even with unmatched route
 			if ($processed_uri === NULL)
 			{
-				throw new HTTP_Exception_404('Unable to find a route to match the URI: :uri', array(
-					':uri' => $uri,
-				));
+				$this->_uri = $uri;
+				return;
 			}
 
 			// Store the URI
@@ -824,11 +854,17 @@ class Kohana_Request implements HTTP_Request {
 			// Store the URI
 			$this->_uri = $uri;
 
+			// Set the security setting if required
+			if (strpos($uri, 'https://') === 0)
+			{
+				$this->secure(TRUE);
+			}
+
 			// Set external state
 			$this->_external = TRUE;
 
 			// Setup the client
-			$this->_client = new Request_Client_External(array('cache' => $cache));
+			$this->_client = Request_Client_External::factory(array('cache' => $cache));
 		}
 	}
 
@@ -845,46 +881,23 @@ class Kohana_Request implements HTTP_Request {
 	}
 
 	/**
-	 * Generates a relative URI for the current route.
+	 * Returns the URI for the current route.
 	 *
-	 *     $request->uri($params);
+	 *     $request->uri();
 	 *
 	 * @param   array   $params  Additional route parameters
 	 * @return  string
 	 * @uses    Route::uri
 	 */
-	public function uri(array $params = NULL)
+	public function uri()
 	{
-		if ( ! isset($params['directory']))
-		{
-			// Add the current directory
-			$params['directory'] = $this->directory();
-		}
-
-		if ( ! isset($params['controller']))
-		{
-			// Add the current controller
-			$params['controller'] = $this->controller();
-		}
-
-		if ( ! isset($params['action']))
-		{
-			// Add the current action
-			$params['action'] = $this->action();
-		}
-
-		// Add the current parameters
-		$params += $this->_params;
-
-		$uri = $this->_route->uri($params);
-
-		return $uri;
+		return empty($this->_uri) ? '/' : $this->_uri;
 	}
 
 	/**
-	 * Create a URL from the current request. This is a shortcut for:
+	 * Create a URL string from the current request. This is a shortcut for:
 	 *
-	 *     echo URL::site($this->request->uri($params), $protocol);
+	 *     echo URL::site($this->request->uri(), $protocol);
 	 *
 	 * @param   array    $params    URI parameters
 	 * @param   mixed    $protocol  protocol string or Request object
@@ -892,12 +905,10 @@ class Kohana_Request implements HTTP_Request {
 	 * @since   3.0.7
 	 * @uses    URL::site
 	 */
-	public function url(array $params = NULL, $protocol = NULL)
+	public function url($protocol = NULL)
 	{
 		// Create a URI with the current route and convert it to a URL
-		$url = URL::site($this->uri($params), $protocol);
-
-		return $url;
+		return URL::site($this->uri(), $protocol);
 	}
 
 	/**
@@ -920,27 +931,6 @@ class Kohana_Request implements HTTP_Request {
 		return isset($this->_params[$key]) ? $this->_params[$key] : $default;
 	}
 
-	/**
-	 * Sends the response status and all set headers. The current server
-	 * protocol (HTTP/1.0 or HTTP/1.1) will be used when available. If not
-	 * available, HTTP/1.1 will be used.
-	 *
-	 *     $request->send_headers();
-	 *
-	 * @return  $this
-	 * @uses    Request::$messages
-	 * @deprecated This should not be here, it belongs in\n
-	 * Response::send_headers() where it is implemented correctly.
-	 */
-	public function send_headers()
-	{
-		if ( ! ($response = $this->response()) instanceof Response)
-			return $this;
-
-		$response->send_headers();
-		return $this;
-	}
-
 	/**
 	 * Redirects as the request response. If the URL does not include a
 	 * protocol, it will be converted into a complete URL.
@@ -958,16 +948,17 @@ class Kohana_Request implements HTTP_Request {
 	public function redirect($url = '', $code = 302)
 	{
 		$referrer = $this->uri();
+		$protocol = ($this->secure()) ? 'https' : TRUE;
 
 		if (strpos($referrer, '://') === FALSE)
 		{
-			$referrer = URL::site($referrer, TRUE, Kohana::$index_file);
+			$referrer = URL::site($referrer, $protocol, ! empty(Kohana::$index_file));
 		}
 
 		if (strpos($url, '://') === FALSE)
 		{
 			// Make the URI into a URL
-			$url = URL::site($url, TRUE, Kohana::$index_file);
+			$url = URL::site($url, TRUE, ! empty(Kohana::$index_file));
 		}
 
 		if (($response = $this->response()) === NULL)
@@ -1086,15 +1077,20 @@ class Kohana_Request implements HTTP_Request {
 	}
 
 	/**
-	 * Provides readonly access to the [Request_Client],
-	 * useful for accessing the caching methods within the
-	 * request client.
+	 * Provides access to the [Request_Client].
 	 *
 	 * @return  Request_Client
+	 * @return  self
 	 */
-	public function get_client()
+	public function client(Request_Client $client = NULL)
 	{
-		return $this->_client;
+		if ($client === NULL)
+			return $this->_client;
+		else
+		{
+			$this->_client = $client;
+			return $this;
+		}
 	}
 
 	/**
@@ -1134,15 +1130,23 @@ class Kohana_Request implements HTTP_Request {
 	 *     $request->execute();
 	 *
 	 * @return  Response
-	 * @throws  Kohana_Exception
+	 * @throws  Request_Exception
+	 * @throws  HTTP_Exception_404
 	 * @uses    [Kohana::$profiling]
 	 * @uses    [Profiler]
 	 */
 	public function execute()
 	{
-		if ( ! $this->_client instanceof Kohana_Request_Client)
+		if ( ! $this->_route instanceof Route)
 		{
-			throw new Kohana_Request_Exception('Unable to execute :uri without a Kohana_Request_Client', array(
+			throw new HTTP_Exception_404('Unable to find a route to match the URI: :uri', array(
+				':uri' => $this->_uri,
+			));
+		}
+
+		if ( ! $this->_client instanceof Request_Client)
+		{
+			throw new Request_Exception('Unable to execute :uri without a Kohana_Request_Client', array(
 				':uri' => $this->_uri,
 			));
 		}
@@ -1164,6 +1168,19 @@ class Kohana_Request implements HTTP_Request {
 		return ($this === Request::$initial);
 	}
 
+	/**
+	 * Readonly access to the [Request::$_external] property.
+	 *
+	 *     if ( ! $request->is_external())
+	 *          // This is an internal request
+	 *
+	 * @return  boolean
+	 */
+	public function is_external()
+	{
+		return $this->_external;
+	}
+
 	/**
 	 * Returns whether this is an ajax request (as used by JS frameworks)
 	 *
@@ -1184,13 +1201,13 @@ class Kohana_Request implements HTTP_Request {
 	 * exception will be thrown!
 	 *
 	 * @return string
-	 * @throws Kohana_Request_Exception
+	 * @throws Request_Exception
 	 */
 	public function generate_etag()
 	{
 	    if ($this->_response === NULL)
 		{
-			throw new Kohana_Request_Exception('No response yet associated with request - cannot auto generate resource ETag');
+			throw new Request_Exception('No response yet associated with request - cannot auto generate resource ETag');
 		}
 
 		// Generate a unique hash for the response
@@ -1265,8 +1282,8 @@ class Kohana_Request implements HTTP_Request {
 	}
 
 	/**
-	 * Gets or sets the HTTP protocol. The standard protocol to use
-	 * is `http`.
+	 * Gets or sets the HTTP protocol. If there is no current protocol set,
+	 * it will use the default set in HTTP::$protocol
 	 *
 	 * @param   string   $protocol  Protocol to set to the request/response
 	 * @return  mixed
@@ -1276,20 +1293,30 @@ class Kohana_Request implements HTTP_Request {
 		if ($protocol === NULL)
 		{
 			if ($this->_protocol)
-			{
-				// Act as a getter
 				return $this->_protocol;
-			}
 			else
-			{
-				// Get the default protocol
-				return HTTP::$protocol;
-			}
+				return $this->_protocol = HTTP::$protocol;
 		}
 
 		// Act as a setter
-		$this->_protocol = strtolower($protocol);
+		$this->_protocol = strtoupper($protocol);
+		return $this;
+	}
 
+	/**
+	 * Getter/Setter to the security settings for this request. This
+	 * method should be treated as immutable.
+	 *
+	 * @param   boolean $secure is this request secure?
+	 * @return  mixed
+	 */
+	public function secure($secure = NULL)
+	{
+		if ($secure === NULL)
+			return $this->_secure;
+
+		// Act as a setter
+		$this->_secure = (bool) $secure;
 		return $this;
 	}
 
@@ -1398,6 +1425,17 @@ class Kohana_Request implements HTTP_Request {
 		return $this;
 	}
 
+	/**
+	 * Returns the length of the body for use with
+	 * content header
+	 *
+	 * @return  integer
+	 */
+	public function content_length()
+	{
+		return strlen($this->body());
+	}
+
 	/**
 	 * Renders the HTTP_Interaction to a string, producing
 	 *
@@ -1411,14 +1449,8 @@ class Kohana_Request implements HTTP_Request {
 	 * @param   boolean  $response  Return the rendered response, else returns the rendered request
 	 * @return  string
 	 */
-	public function render($response = TRUE)
+	public function render()
 	{
-		if ($response)
-		{
-			// Act as a getter
-			return (string) $this->_response;
-		}
-
 		if ( ! $post = $this->post())
 		{
 			$body = $this->body();
@@ -1429,6 +1461,15 @@ class Kohana_Request implements HTTP_Request {
 			$body = http_build_query($post, NULL, '&');
 		}
 
+		// Set the content length
+		$this->headers('content-length', (string) $this->content_length());
+
+		// If Kohana expose, set the user-agent
+		if (Kohana::$expose)
+		{
+			$this->headers('user-agent', 'Kohana Framework '.Kohana::VERSION.' ('.Kohana::CODENAME.')');
+		}
+
 		// Prepare cookies
 		if ($this->_cookies)
 		{
@@ -1444,7 +1485,7 @@ class Kohana_Request implements HTTP_Request {
 			$this->_header['cookie'] = implode('; ', $cookie_string);
 		}
 
-		$output = $this->method().' '.$this->uri($this->param()).' '.strtoupper($this->protocol()).'/'.HTTP::$version."\n";
+		$output = $this->method().' '.$this->uri().' '.$this->protocol()."\r\n";
 		$output .= (string) $this->_header;
 		$output .= $body;
 
