@@ -1,4 +1,4 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 /**
  * Response wrapper. Created as the result of any [Request] execution
  * or utility method (i.e. Redirect). Implements standard HTTP
@@ -7,11 +7,11 @@
  * @package    Kohana
  * @category   Base
  * @author     Kohana Team
- * @copyright  (c) 2008-2012 Kohana Team
+ * @copyright  (c) 2008-2011 Kohana Team
  * @license    http://kohanaphp.com/license
  * @since      3.1.0
  */
-class Kohana_Response implements HTTP_Response, Serializable {
+class Kohana_Response implements HTTP_Response {
 
 	/**
 	 * Factory method to create a new [Response]. Pass properties
@@ -31,71 +31,6 @@ class Kohana_Response implements HTTP_Response, Serializable {
 		return new Response($config);
 	}
 
-	/**
-	 * Generates a [Cache-Control HTTP](http://en.wikipedia.org/wiki/List_of_HTTP_headers)
-	 * header based on the supplied array.
-	 *
-	 *     // Set the cache control headers you want to use
-	 *     $cache_control = array(
-	 *         'max-age'          => 3600,
-	 *         'must-revalidate'  => NULL,
-	 *         'public'           => NULL
-	 *     );
-	 *
-	 *     // Create the cache control header, creates :
-	 *     // cache-control: max-age=3600, must-revalidate, public
-	 *     $response->header['cache-control'] = Response::create_cache_control($cache_control);
-	 *
-	 * @param   array    $cache_control Cache_control parts to render
-	 * @return  string
-	 */
-	public static function create_cache_control(array $cache_control)
-	{
-		// Create a buffer
-		$parts = array();
-
-		// Foreach cache control entry
-		foreach ($cache_control as $key => $value)
-		{
-			// Create a cache control fragment
-			$parts[] = empty($value) ? $key : ($key.'='.$value);
-		}
-		// Return the rendered parts
-		return implode(', ', $parts);
-	}
-
-	/**
-	 * Parses the Cache-Control header and returning an array representation of the Cache-Control
-	 * header.
-	 *
-	 *     // Create the cache control header
-	 *     $response->header['cache-control'] = 'max-age=3600, must-revalidate, public';
-	 *
-	 *     // Parse the cache control header
-	 *     if ($cache_control = Request::parse_cache_control($response->header['cache-control']))
-	 *     {
-	 *          // Cache-Control header was found
-	 *          $maxage = $cache_control['max-age'];
-	 *     }
-	 *
-	 * @param   array   $cache_control Array of headers
-	 * @return  mixed
-	 */
-	public static function parse_cache_control($cache_control)
-	{
-		// If no Cache-Control parts are detected
-		if ( (bool) preg_match_all('/(?<key>[a-z\-]+)=?(?<value>\w+)?/', $cache_control, $matches))
-		{
-			// Return combined cache-control key/value pairs
-			return array_combine($matches['key'], $matches['value']);
-		}
-		else
-		{
-			// Return
-			return FALSE;
-		}
-	}
-
 	// HTTP status codes and messages
 	public static $messages = array(
 		// Informational 1xx
@@ -184,7 +119,7 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	 */
 	public function __construct(array $config = array())
 	{
-		$this->_header = new HTTP_Header(array());
+		$this->_header = new HTTP_Header;
 
 		foreach ($config as $key => $value)
 		{
@@ -237,10 +172,15 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	{
 		if ($protocol)
 		{
-			$this->_protocol = $protocol;
+			$this->_protocol = strtoupper($protocol);
 			return $this;
 		}
 
+		if ($this->_protocol === NULL)
+		{
+			$this->_protocol = HTTP::$protocol;
+		}
+
 		return $this->_protocol;
 	}
 
@@ -325,7 +265,7 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	 */
 	public function content_length()
 	{
-		return strlen($this->_body);
+		return strlen($this->body());
 	}
 
 	/**
@@ -340,8 +280,8 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	 *          'expiration' => 12352234
 	 *     ));
 	 *
-	 * @param   mixed   $key    cookie name, or array of cookie values
-	 * @param   string  $value  value to set to cookie
+	 * @param   mixed     cookie name, or array of cookie values
+	 * @param   string    value to set to cookie
 	 * @return  string
 	 * @return  void
 	 * @return  [Response]
@@ -386,7 +326,7 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	/**
 	 * Deletes a cookie set to the response
 	 *
-	 * @param   string  $name
+	 * @param   string   name
 	 * @return  Response
 	 */
 	public function delete_cookie($name)
@@ -409,68 +349,13 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	/**
 	 * Sends the response status and all set headers.
 	 *
-	 * @return  Response
+	 * @param   boolean   replace existing headers
+	 * @param   callback  function to handle header output
+	 * @return  mixed
 	 */
-	public function send_headers()
+	public function send_headers($replace = FALSE, $callback = NULL)
 	{
-		if ( ! headers_sent())
-		{
-			if (isset($_SERVER['SERVER_PROTOCOL']))
-			{
-				// Use the default server protocol
-				$protocol = $_SERVER['SERVER_PROTOCOL'];
-			}
-			else
-			{
-				// Default to using newer protocol
-				$protocol = strtoupper(HTTP::$protocol).'/'.HTTP::$version;
-			}
-
-			// Default to text/html; charset=utf8 if no content type set
-			if ( ! $this->_header->offsetExists('content-type'))
-			{
-				$this->_header['content-type'] = Kohana::$content_type.'; charset='.Kohana::$charset;
-			}
-
-			// Add the X-Powered-By header
-			if (Kohana::$expose)
-			{
-				$this->_header['x-powered-by'] = 'Kohana Framework '.Kohana::VERSION.' ('.Kohana::CODENAME.')';
-			}
-
-			if ( ! Kohana::$is_cli)
-			{
-				// HTTP status line
-				header($protocol.' '.$this->_status.' '.Response::$messages[$this->_status]);
-
-				foreach ($this->_header as $name => $value)
-				{
-					if (is_string($name))
-					{
-						// If the value is an array
-						if (is_array($value))
-						{
-							// Render this correctly
-							$value = implode(', ', $value);
-						}
-
-						// Combine the name and value to make a raw header
-						$value = $name.': '.(string) $value;
-					}
-
-					// Send the raw header
-					header($value, TRUE);
-				}
-			}
-
-			// Send cookies
-			foreach ($this->_cookies as $name => $value)
-			{
-				Cookie::set($name, $value['value'], $value['expiration']);
-			}
-		}
-
-		return $this;
+		return $this->_header->send_headers($this, $replace, $callback);
 	}
 
 	/**
@@ -496,9 +381,9 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	 *
 	 * [!!] No further processing can be done after this method is called!
 	 *
-	 * @param   string  $filename   filename with path, or TRUE for the current response
-	 * @param   string  $download   downloaded file name
-	 * @param   array   $options    additional options
+	 * @param   string   filename with path, or TRUE for the current response
+	 * @param   string   downloaded file name
+	 * @param   array    additional options
 	 * @return  void
 	 * @throws  Kohana_Exception
 	 * @uses    File::mime_by_ext
@@ -602,7 +487,7 @@ class Kohana_Response implements HTTP_Response, Serializable {
 		if (Request::user_agent('browser') === 'Internet Explorer')
 		{
 			// Naturally, IE does not act like a real browser...
-			if (Request::$initial->protocol() === 'https')
+			if (Request::$initial->secure())
 			{
 				// http://support.microsoft.com/kb/316431
 				$this->_header['pragma'] = $this->_header['cache-control'] = 'public';
@@ -705,12 +590,13 @@ class Kohana_Response implements HTTP_Response, Serializable {
 			$this->_header['content-type'] = Kohana::$content_type.'; charset='.Kohana::$charset;
 		}
 
-		$content_length = $this->content_length();
+		// Set the content length
+		$this->headers('content-length', (string) $this->content_length());
 
-		// Set the content length for the body if required
-		if ($content_length > 0)
+		// If Kohana expose, set the user-agent
+		if (Kohana::$expose)
 		{
-			$this->_header['content-length'] = (string) $content_length;
+			$this->headers('user-agent', 'Kohana Framework '.Kohana::VERSION.' ('.Kohana::CODENAME.')');
 		}
 
 		// Prepare cookies
@@ -736,7 +622,7 @@ class Kohana_Response implements HTTP_Response, Serializable {
 			}
 		}
 
-		$output = $this->_protocol.' '.$this->_status.' '.Response::$messages[$this->_status]."\n";
+		$output = $this->_protocol.' '.$this->_status.' '.Response::$messages[$this->_status]."\r\n";
 		$output .= (string) $this->_header;
 		$output .= $this->_body;
 
@@ -747,14 +633,14 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	 * Generate ETag
 	 * Generates an ETag from the response ready to be returned
 	 *
-	 * @throws Kohana_Request_Exception
+	 * @throws Request_Exception
 	 * @return String Generated ETag
 	 */
 	public function generate_etag()
 	{
 	    if ($this->_body === NULL)
 		{
-			throw new Kohana_Request_Exception('No response yet associated with request - cannot auto generate resource ETag');
+			throw new Request_Exception('No response yet associated with request - cannot auto generate resource ETag');
 		}
 
 		// Generate a unique hash for the response
@@ -768,7 +654,7 @@ class Kohana_Response implements HTTP_Response, Serializable {
 	 * @param   string   $etag Resource ETag
 	 * @param   Request  $request The request to test against
 	 * @return  Response
-	 * @throws  Kohana_Request_Exception
+	 * @throws  Request_Exception
 	 */
 	public function check_cache($etag = NULL, Request $request = NULL)
 	{
@@ -778,7 +664,7 @@ class Kohana_Response implements HTTP_Response, Serializable {
 		}
 
 		if ( ! $request)
-			throw new Kohana_Request_Exception('A Request object must be supplied with an etag for evaluation');
+			throw new Request_Exception('A Request object must be supplied with an etag for evaluation');
 
 		// Set the ETag header
 		$this->_header['etag'] = $etag;
@@ -814,69 +700,11 @@ class Kohana_Response implements HTTP_Response, Serializable {
 		return $this;
 	}
 
-	/**
-	 * Serializes the object
-	 *
-	 * @param   array    array of data to serialize
-	 * @return  string
-	 * @throws  Kohana_Exception
-	 */
-	public function serialize(array $to_serialize = array())
-	{
-		// Serialize the class properties
-		$to_serialize += array
-		(
-			'_status'  => $this->_status,
-			'_header'  => $this->_header,
-			'_cookies' => $this->_cookies,
-			'_body'    => $this->_body
-		);
-
-		$serialized = serialize($to_serialize);
-
-		if (is_string($serialized))
-		{
-			return $serialized;
-		}
-		else
-		{
-			throw new Kohana_Exception('Unable to serialize object');
-		}
-	}
-
-	/**
-	 * PHP serialized object
-	 *
-	 * @param   string   php serialized string
-	 * @return  bool
-	 * @throws  Kohana_Exception
-	 */
-	public function unserialize($string)
-	{
-		// Unserialise object
-		$unserialized = unserialize($string);
-
-		// If failed
-		if ($unserialized === NULL)
-		{
-			// Throw exception
-			throw new Kohana_Exception('Unable to correctly unserialize string: :string', array(':string' => $string));
-		}
-
-		// Foreach key/value pair
-		foreach ($unserialized as $key => $value)
-		{
-			$this->$key = $value;
-		}
-
-		return TRUE;
-	}
-
 	/**
 	 * Parse the byte ranges from the HTTP_RANGE header used for
 	 * resumable downloads.
 	 *
-	 * @link   http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35
+	 * @see http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35
 	 * @return array|FALSE
 	 */
 	protected function _parse_byte_range()
