@@ -1,9 +1,9 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 /**
  * @package    Kohana
  * @category   Exceptions
  * @author     Kohana Team
- * @copyright  (c) 2009-2012 Kohana Team
+ * @copyright  (c) 2009-2011 Kohana Team
  * @license    http://kohanaframework.org/license
  */
 class Kohana_View_Exception extends Kohana_Exception {  }
