@@ -1,3 +1,3 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 
 abstract class Request_Client extends Kohana_Request_Client {}
\ No newline at end of file
