@@ -1,3 +1,3 @@
-<?php defined('SYSPATH') OR die('No direct script access.');
+<?php defined('SYSPATH') or die('No direct script access.');
 
 class Request_Client_Internal extends Kohana_Request_Client_Internal {}
\ No newline at end of file
