@@ -50,22 +50,49 @@ return array(
 	),
 
 	'irregular' => array(
+		'appendix' => 'appendices',
+		'cactus' => 'cacti',
+		'calf' => 'calves',
 		'child' => 'children',
-		'clothes' => 'clothing',
-		'man' => 'men',
-		'movie' => 'movies',
-		'person' => 'people',
-		'woman' => 'women',
-		'mouse' => 'mice',
+		'crisis' => 'crises',
+		'criterion' => 'criteria',
+		'curriculum' => 'curricula',
+		'diagnosis' => 'diagnoses',
+		'elf' => 'elves',
+		'ellipsis' => 'ellipses',
+		'foot' => 'feet',
 		'goose' => 'geese',
-		'ox' => 'oxen',
-		'leaf' => 'leaves',
-		'course' => 'courses',
-		'size' => 'sizes',
-		'was' => 'were',
-		'is' => 'are',
-		'verse' => 'verses',
 		'hero' => 'heroes',
-		'purchase' => 'purchases',
+		'hoof' => 'hooves',
+		'hypothesis' => 'hypotheses',
+		'is' => 'are',
+		'knife' => 'knives',
+		'leaf' => 'leaves',
+		'life' => 'lives',
+		'loaf' => 'loaves',
+		'man' => 'men',
+		'mouse' => 'mice',
+		'nucleus' => 'nuclei',
+		'oasis' => 'oases',
+		'octopus' => 'octopi',
+		'ox' => 'oxen',
+		'paralysis' => 'paralyses',
+		'parenthesis' => 'parentheses',
+		'person' => 'people',
+		'phenomenon' => 'phenomena',
+		'potato' => 'potatoes',
+		'quiz' => 'quizzes',
+		'radius' => 'radii',
+		'scarf' => 'scarves',
+		'stimulus' => 'stimuli',
+		'syllabus' => 'syllabi',
+		'synthesis' => 'syntheses',
+		'thief' => 'thieves',
+		'tooth' => 'teeth',
+		'was' => 'were',
+		'wharf' => 'wharves',
+		'wife' => 'wives',
+		'woman' => 'women',
+		'release' => 'releases',
 	),
 );
