@@ -30,7 +30,11 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('!"£$(G$W£(HFW£F(HQ)"n', FALSE),
 			// UTF-8 tests
 			array('あいうえお', TRUE, TRUE),
-			array('¥', FALSE, TRUE)
+			array('¥', FALSE, TRUE),
+			// Empty test
+			array('', FALSE, FALSE),
+			array(NULL, FALSE, FALSE),
+			array(FALSE, FALSE, FALSE),
 		);
 	}
 
@@ -59,18 +63,22 @@ class Kohana_ValidTest extends Unittest_TestCase
 	{
 		return array(
 			array('abcd1234',  TRUE),
-		    array('abcd',      TRUE),
-		    array('1234',      TRUE),
-		    array('abc123&^/-', FALSE),
+			array('abcd',      TRUE),
+			array('1234',      TRUE),
+			array('abc123&^/-', FALSE),
 			// UTF-8 tests
 			array('あいうえお', TRUE, TRUE),
 			array('零一二三四五', TRUE, TRUE),
 			array('あい四五£^£^', FALSE, TRUE),
+			// Empty test
+			array('', FALSE, FALSE),
+			array(NULL, FALSE, FALSE),
+			array(FALSE, FALSE, FALSE),
 		);
 	}
 
 	/**
-	 * Tests Valid::alpha_numberic()
+	 * Tests Valid::alpha_numeric()
 	 *
 	 * Checks whether a string consists of alphabetical characters and numbers only.
 	 *
@@ -94,10 +102,14 @@ class Kohana_ValidTest extends Unittest_TestCase
 	{
 		return array(
 			array('abcdef',     TRUE),
-		    array('12345',      TRUE),
-		    array('abcd1234',   TRUE),
-		    array('abcd1234-',  TRUE),
-		    array('abc123&^/-', FALSE)
+			array('12345',      TRUE),
+			array('abcd1234',   TRUE),
+			array('abcd1234-',  TRUE),
+			array('abc123&^/-', FALSE),
+			// Empty test
+			array('', FALSE),
+			array(NULL, FALSE),
+			array(FALSE, FALSE),
 		);
 	}
 
@@ -145,6 +157,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('blarg',FALSE),
 			array('in the year 2000',FALSE),
 			array('324824',FALSE),
+			// Empty test
+			array('', FALSE),
+			array(NULL, FALSE),
+			array(FALSE, FALSE),
 		);
 	}
 
@@ -170,9 +186,16 @@ class Kohana_ValidTest extends Unittest_TestCase
 	public function provider_decimal()
 	{
 		return array(
-			array('45.1664',  3,    NULL, FALSE),
-			array('45.1664',  4,    NULL, TRUE),
-			array('45.1664',  4,    2,    TRUE),
+			// Empty test
+			array('', 2, NULL, FALSE),
+			array(NULL, 2, NULL, FALSE),
+			array(FALSE, 2, NULL, FALSE),
+			array('45.1664', 3, NULL, FALSE),
+			array('45.1664', 4, NULL, TRUE),
+			array('45.1664', 4, 2, TRUE),
+			array('-45.1664', 4, NULL, TRUE),
+			array('+45.1664', 4, NULL, TRUE),
+			array('-45.1664', 3, NULL, FALSE),
 		);
 	}
 
@@ -208,6 +231,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('abcd1234', FALSE),
 			array('-5',       FALSE),
 			array(-5,         FALSE),
+			// Empty test
+			array('',         FALSE),
+			array(NULL,       FALSE),
+			array(FALSE,      FALSE),
 		);
 	}
 
@@ -252,7 +279,11 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('GGGGGG', FALSE),
 			array('AbCdEf', TRUE),
 			array('000', TRUE),
-			array('DEF', TRUE)
+			array('DEF', TRUE),
+			// Empty test
+			array('', FALSE),
+			array(NULL, FALSE),
+			array(FALSE, FALSE),
 		);
 	}
 
@@ -279,14 +310,18 @@ class Kohana_ValidTest extends Unittest_TestCase
 	{
 		return array(
 			array('4222222222222',    'visa',       TRUE),
-		    array('4012888888881881', 'visa',       TRUE),
-		    array('4012888888881881', NULL,         TRUE),
-		    array('4012888888881881', array('mastercard', 'visa'), TRUE),
-		    array('4012888888881881', array('discover', 'mastercard'), FALSE),
-		    array('4012888888881881', 'mastercard', FALSE),
-		    array('5105105105105100', 'mastercard', TRUE),
-		    array('6011111111111117', 'discover',   TRUE),
-		    array('6011111111111117', 'visa',       FALSE)
+			array('4012888888881881', 'visa',       TRUE),
+			array('4012888888881881', NULL,         TRUE),
+			array('4012888888881881', array('mastercard', 'visa'), TRUE),
+			array('4012888888881881', array('discover', 'mastercard'), FALSE),
+			array('4012888888881881', 'mastercard', FALSE),
+			array('5105105105105100', 'mastercard', TRUE),
+			array('6011111111111117', 'discover',   TRUE),
+			array('6011111111111117', 'visa',       FALSE),
+			// Empty test
+			array('', NULL, FALSE),
+			array(NULL, NULL, FALSE),
+			array(FALSE, NULL, FALSE),
 		);
 	}
 
@@ -322,6 +357,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('6011111111111117X', FALSE),
 			array('6011111111111117 ', FALSE),
 			array('WORD ', FALSE),
+			// Empty test
+			array('', FALSE),
+			array(NULL, FALSE),
+			array(FALSE, FALSE),
 		);
 	}
 
@@ -353,13 +392,21 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('foo', TRUE,  FALSE),
 			array('foo', FALSE, FALSE),
 
+			array('foo@bar', TRUE, TRUE),
 			// RFC is less strict than the normal regex, presumably to allow
 			//  admin@localhost, therefore we IGNORE IT!!!
 			array('foo@bar', FALSE, FALSE),
 			array('foo@bar.com', FALSE, TRUE),
+			array('foo@barcom:80', FALSE, FALSE),
 			array('foo@bar.sub.com', FALSE, TRUE),
 			array('foo+asd@bar.sub.com', FALSE, TRUE),
 			array('foo.asd@bar.sub.com', FALSE, TRUE),
+			// RFC says 254 length max #4011
+			array(Text::random(NULL, 200).'@'.Text::random(NULL, 50).'.com', FALSE, FALSE),
+			// Empty test
+			array('', TRUE, FALSE),
+			array(NULL, TRUE, FALSE),
+			array(FALSE, TRUE, FALSE),
 		);
 	}
 
@@ -392,7 +439,11 @@ class Kohana_ValidTest extends Unittest_TestCase
 		return array(
 			array('google.com', TRUE),
 			// Don't anybody dare register this...
-			array('DAWOMAWIDAIWNDAIWNHDAWIHDAIWHDAIWOHDAIOHDAIWHD.com', FALSE)
+			array('DAWOMAWIDAIWNDAIWNHDAWIHDAIWHDAIWOHDAIOHDAIWHD.com', FALSE),
+			// Empty test
+			array('', FALSE),
+			array(NULL, FALSE),
+			array(FALSE, FALSE),
 		);
 	}
 
@@ -438,7 +489,15 @@ class Kohana_ValidTest extends Unittest_TestCase
 	{
 		return array(
 			array('somestring', 10, TRUE),
+			array('somestring', 11, FALSE),
 			array('anotherstring', 13, TRUE),
+			// Empty test
+			array('', 10, FALSE),
+			array(NULL, 10, FALSE),
+			array(FALSE, 10, FALSE),
+			// Test array of allowed lengths
+			array('somestring', array(1, 3, 5, 7, 9, 10), TRUE),
+			array('somestring', array(1, 3, 5, 7, 9), FALSE),
 		);
 	}
 
@@ -476,6 +535,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('1', '1', TRUE),
 			array(1, '1', FALSE),
 			array('011', 011, FALSE),
+			// Empty test
+			array('', 123, FALSE),
+			array(NULL, 123, FALSE),
+			array(FALSE, 123, FALSE),
 		);
 	}
 
@@ -507,11 +570,15 @@ class Kohana_ValidTest extends Unittest_TestCase
 		return array(
 			array('75.125.175.50',   FALSE, TRUE),
 			// PHP 5.3.6 fixed a bug that allowed 127.0.0.1 as a public ip: http://bugs.php.net/53150
-		    array('127.0.0.1',       FALSE, version_compare(PHP_VERSION, '5.3.6', '<')),
-		    array('256.257.258.259', FALSE, FALSE),
-		    array('255.255.255.255', FALSE, FALSE),
-		    array('192.168.0.1',     FALSE, FALSE),
-		    array('192.168.0.1',     TRUE,  TRUE)
+			array('127.0.0.1',       FALSE, version_compare(PHP_VERSION, '5.3.6', '<')),
+			array('256.257.258.259', FALSE, FALSE),
+			array('255.255.255.255', FALSE, FALSE),
+			array('192.168.0.1',     FALSE, FALSE),
+			array('192.168.0.1',     TRUE,  TRUE),
+			// Empty test
+			array('', TRUE, FALSE),
+			array(NULL, TRUE, FALSE),
+			array(FALSE, TRUE, FALSE),
 		);
 	}
 
@@ -545,7 +612,11 @@ class Kohana_ValidTest extends Unittest_TestCase
 			// Exceeds
 			array('KOHANARULLLES', 2, FALSE),
 			// Under
-			array('CakeSucks', 10, TRUE)
+			array('CakeSucks', 10, TRUE),
+			// Empty test
+			array('', -10, FALSE),
+			array(NULL, -10, FALSE),
+			array(FALSE, -10, FALSE),
 		);
 	}
 
@@ -578,7 +649,11 @@ class Kohana_ValidTest extends Unittest_TestCase
 		return array(
 			array('This is obviously long enough', 10, TRUE),
 			array('This is not', 101, FALSE),
-			array('This is on the borderline', 25, TRUE)
+			array('This is on the borderline', 25, TRUE),
+			// Empty test
+			array('', 10, FALSE),
+			array(NULL, 10, FALSE),
+			array(FALSE, 10, FALSE),
 		);
 	}
 
@@ -669,6 +744,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('-5.',   TRUE),
 			array('.',     FALSE),
 			array('1.2.3', FALSE),
+			// Empty test
+			array('', FALSE),
+			array(NULL, FALSE),
+			array(FALSE, FALSE),
 		);
 	}
 
@@ -696,8 +775,8 @@ class Kohana_ValidTest extends Unittest_TestCase
 	{
 		return array(
 			array('0163634840',       NULL, TRUE),
-		    array('+27173634840',     NULL, TRUE),
-		    array('123578',           NULL, FALSE),
+			array('+27173634840',     NULL, TRUE),
+			array('123578',           NULL, FALSE),
 			// Some uk numbers
 			array('01234456778',      NULL, TRUE),
 			array('+0441234456778',   NULL, FALSE),
@@ -705,6 +784,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('+44 20-7031-3000', array(12), TRUE),
 			// BT Corporate
 			array('020 7356 5000',	  NULL, TRUE),
+			// Empty test
+			array('', NULL, FALSE),
+			array(NULL, NULL, FALSE),
+			array(FALSE, NULL, FALSE),
 		);
 	}
 
@@ -734,6 +817,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('123456789', '/[0-9]++/', TRUE),
 			array('£$%£%', '/[abc]/', FALSE),
 			array('Good evening',  '/hello/',  FALSE),
+			// Empty test
+			array('', '/hello/', FALSE),
+			array(NULL, '/hello/', FALSE),
+			array(FALSE, '/hello/', FALSE),
 		);
 	}
 
@@ -767,7 +854,11 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array(-1, 0,  1, FALSE),
 			array(1,  0,  0, FALSE),
 			array(2147483647, 0, 200000000000000, TRUE),
-			array(-2147483647, -2147483655, 2147483645, TRUE)
+			array(-2147483647, -2147483655, 2147483645, TRUE),
+			// Empty test
+			array('', 5, 10, FALSE),
+			array(NULL, 5, 10, FALSE),
+			array(FALSE, 5, 10, FALSE),
 		);
 	}
 
@@ -825,6 +916,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array('http://127.0.0.1.1', FALSE),
 			array('http://user:@127.0.0.1', FALSE),
 			array("http://finalnewline.com\n", FALSE),
+			// Empty test
+			array('', FALSE),
+			array(NULL, FALSE),
+			array(FALSE, FALSE),
 		);
 
 		$data[] = array('http://'.str_repeat('123456789.', 25).'com/', TRUE); // 253 chars
@@ -858,6 +953,10 @@ class Kohana_ValidTest extends Unittest_TestCase
 			array(array('a' => 'hello', 'b' => 'hello'), 'a', 'b', TRUE),
 			array(array('a' => 'hello', 'b' => 'hello '), 'a', 'b', FALSE),
 			array(array('a' => '1', 'b' => 1), 'a', 'b', FALSE),
+			// Empty test
+			array(array('a' => '', 'b' => 'hello'), 'a', 'b', FALSE),
+			array(array('a' => NULL, 'b' => 'hello'), 'a', 'b', FALSE),
+			array(array('a' => FALSE, 'b' => 'hello'), 'a', 'b', FALSE),
 		);
 	}
 
