@@ -4,13 +4,12 @@
  * Tests the View class
  *
  * @group kohana
- * @group kohana.core
- * @group kohana.core.view
+ * @group kohana.view
  *
  * @package    Kohana
  * @category   Tests
  * @author     Kohana Team
- * @copyright  (c) 2008-2012 Kohana Team
+ * @copyright  (c) 2008-2011 Kohana Team
  * @license    http://kohanaframework.org/license
  */
 class Kohana_ViewTest extends Unittest_TestCase
@@ -27,7 +26,7 @@ class Kohana_ViewTest extends Unittest_TestCase
 		self::$old_modules = Kohana::modules();
 
 		$new_modules = self::$old_modules+array(
-			'test_views' => realpath(dirname(__FILE__).'/../test_data/')
+			'test_views' => realpath(__DIR__.'/../test_data/')
 		);
 		Kohana::modules($new_modules);
 	}
@@ -71,7 +70,7 @@ class Kohana_ViewTest extends Unittest_TestCase
 			$view = new View($path);
 			$this->assertSame(FALSE, $expects_exception);
 		}
-		catch(Kohana_View_Exception $e)
+		catch(View_Exception $e)
 		{
 			$this->assertSame(TRUE, $expects_exception);
 		}
